@@ -20,7 +20,6 @@ from unittest.mock import patch
 from clickreviews.common import cleanup_unpack
 from clickreviews.cr_lint import ClickReviewLint
 from clickreviews.cr_lint import MINIMUM_CLICK_FRAMEWORK_VERSION
-from clickreviews.frameworks import FRAMEWORKS_DATA_URL, USER_DATA_FILE
 from clickreviews.tests import utils
 import clickreviews.cr_tests as cr_tests
 
@@ -61,12 +60,12 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         def _mock_frameworks(self, overrides=None):
             self.FRAMEWORKS = {
                 'ubuntu-core-15.04': 'available',
-                'ubuntu-sdk-14.10-qml-dev2': 'available',
+                'ubuntu-sdk-15.04': 'available',
                 'ubuntu-sdk-13.10': 'deprecated',
                 'ubuntu-sdk-14.10-qml-dev1': 'obsolete',
             }
             self.AVAILABLE_FRAMEWORKS = ['ubuntu-core-15.04',
-                                         'ubuntu-sdk-14.10-qml-dev2']
+                                         'ubuntu-sdk-15.04']
             self.OBSOLETE_FRAMEWORKS = ['ubuntu-sdk-14.10-qml-dev1']
             self.DEPRECATED_FRAMEWORKS = ['ubuntu-sdk-13.10']
         p = patch('clickreviews.frameworks.Frameworks.__init__',
@@ -592,73 +591,10 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    def test_check_click_local_extensions_missing(self):
-        '''Testeck_click_local_extensions() - missing'''
-        for k in self.test_manifest.keys():
-            if k.startswith("x-"):
-                self.set_test_manifest(k, None)
-        c = ClickReviewLint(self.test_name)
-        c.check_click_local_extensions()
-        r = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(r, expected_counts)
-
-    def test_check_click_local_extensions_empty(self):
-        '''Testeck_click_local_extensions() - empty'''
-        for k in self.test_manifest.keys():
-            if k.startswith("x-"):
-                self.set_test_manifest(k, None)
-        self.set_test_manifest("x-test", "")
-        c = ClickReviewLint(self.test_name)
-        c.check_click_local_extensions()
-        r = c.click_report
-        expected_counts = {'info': 0, 'warn': 1, 'error': 0}
-        self.check_results(r, expected_counts)
-
-    def test_check_click_local_extensions(self):
-        '''Testeck_click_local_extensions()'''
-        for k in self.test_manifest.keys():
-            if k.startswith("x-"):
-                self.set_test_manifest(k, None)
-        self.set_test_manifest("x-source", {"vcs-bzr": "lp:notes-app",
-                                            "vcs-bzr-revno": "209"})
-        c = ClickReviewLint(self.test_name)
-        c.check_click_local_extensions()
-        r = c.click_report
-        expected_counts = {'info': 0, 'warn': 1, 'error': 0}
-        self.check_results(r, expected_counts)
-
-    def test_check_click_local_extensions_coreapp(self):
-        '''Testeck_click_local_extensions() - coreapp'''
-        for k in self.test_manifest.keys():
-            if k.startswith("x-"):
-                self.set_test_manifest(k, None)
-        self.set_test_manifest("x-source", "foo")
-        c = ClickReviewLint(self.test_name)
-        c.is_core_app = True
-        c.check_click_local_extensions()
-        r = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(r, expected_counts)
-
-    def test_check_click_local_extensions_snappy_1504(self):
-        '''Testeck_click_local_extensions() - snappy 15.04'''
-        self.set_test_pkgfmt("snap", "15.04")
-        for k in self.test_manifest.keys():
-            if k.startswith("x-"):
-                self.set_test_manifest(k, None)
-        self.set_test_manifest("x-source", {"vcs-bzr": "lp:notes-app",
-                                            "vcs-bzr-revno": "209"})
-        c = ClickReviewLint(self.test_name)
-        c.check_click_local_extensions()
-        r = c.click_report
-        expected_counts = {'info': 0, 'warn': 1, 'error': 0}
-        self.check_results(r, expected_counts)
-
     def test_check_framework(self):
         '''Test check_framework()'''
         self.patch_frameworks()
-        self.set_test_manifest("framework", "ubuntu-sdk-14.10-qml-dev2")
+        self.set_test_manifest("framework", "ubuntu-sdk-15.04")
         c = ClickReviewLint(self.test_name)
         c.check_framework()
         r = c.click_report
@@ -669,7 +605,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         '''Test check_framework() - click'''
         self.patch_frameworks()
         self.set_test_manifest("framework",
-                               "ubuntu-sdk-14.10-qml-dev2,ubuntu-core-15.04")
+                               "ubuntu-sdk-15.04,ubuntu-core-15.04")
         c = ClickReviewLint(self.test_name)
         c.is_snap1 = False
         c.check_framework()
@@ -681,7 +617,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         '''Test check_framework() - snappy'''
         self.patch_frameworks()
         self.set_test_manifest("framework",
-                               "ubuntu-sdk-14.10-qml-dev2,ubuntu-core-15.04")
+                               "ubuntu-sdk-15.04,ubuntu-core-15.04")
         c = ClickReviewLint(self.test_name)
         c.is_snap1 = True
         c.check_framework()
@@ -689,22 +625,6 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    @patch('clickreviews.remote.read_cr_file')
-    def test_check_framework_fetches_remote_data(self, mock_read_cr_file):
-        '''Test check_framework()'''
-        mock_read_cr_file.return_value = {
-            'ubuntu-sdk-14.10-qml-dev2': 'available',
-        }
-        self.set_test_manifest("framework", "ubuntu-sdk-14.10-qml-dev2")
-        c = ClickReviewLint(self.test_name)
-        c.check_framework()
-        r = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
-        self.check_results(r, expected_counts)
-        # ensure no local fn is provided when reading frameworks
-        mock_read_cr_file.assert_called_once_with(
-            USER_DATA_FILE, FRAMEWORKS_DATA_URL)
-
     def test_check_framework_bad(self):
         '''Test check_framework() - bad'''
         self.patch_frameworks()
@@ -735,12 +655,8 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    @patch('clickreviews.remote.read_cr_file')
-    def test_check_framework_with_overrides(self, mock_read_cr_file):
+    def test_check_framework_with_overrides(self):
         '''Test check_framework() - using overrides'''
-        mock_read_cr_file.return_value = {
-            'ubuntu-sdk-14.10-qml-dev2': 'available',
-        }
         self.set_test_manifest("framework", "nonexistent")
         overrides = {'framework': {'nonexistent': {'state': 'available'}}}
         c = ClickReviewLint(self.test_name, overrides=overrides)
@@ -749,13 +665,9 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    @patch('clickreviews.remote.read_cr_file')
-    def test_check_framework_with_overrides_obsolete(self, mock_read_cr_file):
+    def test_check_framework_with_overrides_obsolete(self):
         '''Test check_framework() - using override obsoletes available'''
-        fwk = 'ubuntu-sdk-14.10-qml-dev2'
-        mock_read_cr_file.return_value = {
-            '%s' % fwk: 'available',
-        }
+        fwk = 'ubuntu-sdk-15.04'
         self.set_test_manifest("framework", fwk)
         overrides = {'framework': {'%s' % fwk: {'state': 'obsolete'}}}
         c = ClickReviewLint(self.test_name, overrides=overrides)
@@ -764,13 +676,9 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    @patch('clickreviews.remote.read_cr_file')
-    def test_check_framework_with_overrides_deprecated(self, mock_read_cr_file):
+    def test_check_framework_with_overrides_deprecated(self):
         '''Test check_framework() - using override deprecates available'''
-        fwk = 'ubuntu-sdk-14.10-qml-dev2'
-        mock_read_cr_file.return_value = {
-            '%s' % fwk: 'available',
-        }
+        fwk = 'ubuntu-sdk-15.04'
         self.set_test_manifest("framework", fwk)
         overrides = {'framework': {'%s' % fwk: {'state': 'deprecated'}}}
         c = ClickReviewLint(self.test_name, overrides=overrides)
@@ -779,12 +687,8 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 1, 'error': 0}
         self.check_results(r, expected_counts)
 
-    @patch('clickreviews.remote.read_cr_file')
-    def test_check_framework_with_malformed_overrides(self, mock_read_cr_file):
+    def test_check_framework_with_malformed_overrides(self):
         '''Test check_framework() - using overrides'''
-        mock_read_cr_file.return_value = {
-            'ubuntu-sdk-14.10-qml-dev2': 'available',
-        }
         self.set_test_manifest("framework", "nonexistent")
         overrides = {'nonexistent': {'state': 'available'}}
         c = ClickReviewLint(self.test_name, overrides=overrides)
@@ -864,7 +768,9 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         name = c._get_check_name(
             'sdk_security_extension', app='test-app')
         expected['info'][name] = {
-            "text": "test-app.json does not end with .apparmor (ok if not using sdk)"}
+            "text": ("test-app.json does not end with .apparmor "
+                     "(ok if not using sdk)")
+        }
         self.check_results(r, expected=expected)
 
     def test_check_hooks_bad_appname(self):
@@ -1715,29 +1621,29 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         m = r['error'][name]['text']
         self.assertIn("'files' not found in hashes.yaml", m)
 
-    def test_check_snappy_hashes_archive_files_ok(self):
-        '''Test check_snappy_hashes() - ok'''
-        self.set_test_pkgfmt("snap", "15.04")
-        c = ClickReviewLint(self.test_name)
-        yaml = self._create_hashes_yaml()
-        c.pkg_files = self._test_pkg_files
-        self.set_test_hashes_yaml(yaml)
-        c.check_snappy_hashes()
-        r = c.click_report
-        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
-        self.check_results(r, expected_counts)
+    # def test_check_snappy_hashes_archive_files_ok(self):
+    #     '''Test check_snappy_hashes() - ok'''
+    #     self.set_test_pkgfmt("snap", "15.04")
+    #     c = ClickReviewLint(self.test_name)
+    #     yaml = self._create_hashes_yaml()
+    #     c.pkg_files = self._test_pkg_files
+    #     self.set_test_hashes_yaml(yaml)
+    #     c.check_snappy_hashes()
+    #     r = c.click_report
+    #     expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+    #     self.check_results(r, expected_counts)
 
-    def test_check_snappy_hashes_1504(self):
-        '''Test check_snappy_hashes() - 15.04'''
-        self.set_test_pkgfmt("snap", "15.04")
-        c = ClickReviewLint(self.test_name)
-        yaml = self._create_hashes_yaml()
-        c.pkg_files = self._test_pkg_files
-        self.set_test_hashes_yaml(yaml)
-        c.check_snappy_hashes()
-        r = c.click_report
-        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
-        self.check_results(r, expected_counts)
+    # def test_check_snappy_hashes_1504(self):
+    #     '''Test check_snappy_hashes() - 15.04'''
+    #     self.set_test_pkgfmt("snap", "15.04")
+    #     c = ClickReviewLint(self.test_name)
+    #     yaml = self._create_hashes_yaml()
+    #     c.pkg_files = self._test_pkg_files
+    #     self.set_test_hashes_yaml(yaml)
+    #     c.check_snappy_hashes()
+    #     r = c.click_report
+    #     expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+    #     self.check_results(r, expected_counts)
 
     def test_check_snappy_hashes_archive_files_missing_name(self):
         '''Test check_snappy_hashes() - missing name'''
@@ -1798,7 +1704,8 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
         name = c._get_check_name('file_mode')
         m = r['error'][name]['text']
-        self.assertIn("found errors in hashes.yaml: unusual mode '%s' for entry 'bin/foo'" % "".join(orig_mode), m)
+        self.assertIn("found errors in hashes.yaml: unusual mode '%s' "
+                      "for entry 'bin/foo'" % "".join(orig_mode), m)
 
     def test_check_snappy_hashes_archive_files_mode_world_write(self):
         '''Test check_snappy_hashes() - mode world write'''
@@ -1820,7 +1727,8 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
         name = c._get_check_name('file_mode')
         m = r['error'][name]['text']
-        self.assertIn("found errors in hashes.yaml: 'bin' is world-writable, mode 'frw-rw-rw-' for 'bin/foo' is world-writable", m)
+        self.assertIn("found errors in hashes.yaml: 'bin' is world-writable, "
+                      "mode 'frw-rw-rw-' for 'bin/foo' is world-writable", m)
 
     def test_check_snappy_hashes_archive_files_mode_mismatch(self):
         '''Test check_snappy_hashes() - mode mismatch'''
@@ -1843,38 +1751,42 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
         name = c._get_check_name('file_mode')
         m = r['error'][name]['text']
-        self.assertIn("found errors in hashes.yaml: mode '---------' != '%s' for 'bin/foo'" % orig_mode, m)
+        self.assertIn("found errors in hashes.yaml: mode '---------' != '%s' "
+                      "for 'bin/foo'" % orig_mode, m)
 
-    def test_check_snappy_hashes_archive_files_mode_bad_symlink(self):
-        '''Test check_snappy_hashes() - mode bad symlink'''
-        self.set_test_pkgfmt("snap", "15.04")
-        c = ClickReviewLint(self.test_name)
-        yaml = self._create_hashes_yaml()
-        yaml['files'].append({'name': 'badlink', 'mode': 'lrwxrwxr-x'})
-        self.set_test_hashes_yaml(yaml)
-        c.check_snappy_hashes()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-        name = c._get_check_name('file_mode')
-        m = r['error'][name]['text']
-        self.assertIn("found errors in hashes.yaml: unusual mode 'lrwxrwxr-x' for entry 'badlink'", m)
+    # def test_check_snappy_hashes_archive_files_mode_bad_symlink(self):
+    #     '''Test check_snappy_hashes() - mode bad symlink'''
+    #     self.set_test_pkgfmt("snap", "15.04")
+    #     c = ClickReviewLint(self.test_name)
+    #     yaml = self._create_hashes_yaml()
+    #     yaml['files'].append({'name': 'badlink', 'mode': 'lrwxrwxr-x'})
+    #     self.set_test_hashes_yaml(yaml)
+    #     c.check_snappy_hashes()
+    #     r = c.click_report
+    #     expected_counts = {'info': None, 'warn': 0, 'error': 1}
+    #     self.check_results(r, expected_counts)
+    #     name = c._get_check_name('file_mode')
+    #     m = r['error'][name]['text']
+    #     self.assertIn("found errors in hashes.yaml: unusual mode 'lrwxrwxr-x' "
+    #                   "for entry 'badlink'", m)
 
-    def test_check_snappy_hashes_archive_files_mode_devices(self):
-        '''Test check_snappy_hashes() - mode devices'''
-        self.set_test_pkgfmt("snap", "15.04")
-        c = ClickReviewLint(self.test_name)
-        yaml = self._create_hashes_yaml()
-        yaml['files'].append({'name': 'badblock', 'mode': 'brw-rw-r--'})
-        yaml['files'].append({'name': 'badchar', 'mode': 'crw-rw-r--'})
-        self.set_test_hashes_yaml(yaml)
-        c.check_snappy_hashes()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-        name = c._get_check_name('file_mode')
-        m = r['error'][name]['text']
-        self.assertIn("found errors in hashes.yaml: illegal file mode 'b': 'brw-rw-r--' for 'badblock', illegal file mode 'c': 'crw-rw-r--' for 'badchar'", m)
+    # def test_check_snappy_hashes_archive_files_mode_devices(self):
+    #     '''Test check_snappy_hashes() - mode devices'''
+    #     self.set_test_pkgfmt("snap", "15.04")
+    #     c = ClickReviewLint(self.test_name)
+    #     yaml = self._create_hashes_yaml()
+    #     yaml['files'].append({'name': 'badblock', 'mode': 'brw-rw-r--'})
+    #     yaml['files'].append({'name': 'badchar', 'mode': 'crw-rw-r--'})
+    #     self.set_test_hashes_yaml(yaml)
+    #     c.check_snappy_hashes()
+    #     r = c.click_report
+    #     expected_counts = {'info': None, 'warn': 0, 'error': 1}
+    #     self.check_results(r, expected_counts)
+    #     name = c._get_check_name('file_mode')
+    #     m = r['error'][name]['text']
+    #     self.assertIn("found errors in hashes.yaml: "
+    #                   "illegal file mode 'b': 'brw-rw-r--' for 'badblock', "
+    #                   "illegal file mode 'c': 'crw-rw-r--' for 'badchar'", m)
 
     def test_check_snappy_hashes_archive_files_missing_size(self):
         '''Test check_snappy_hashes() - missing size'''
@@ -1933,22 +1845,22 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    def test_check_snappy_hashes_extra(self):
-        '''Test check_snappy_hashes() - extra'''
-        self.set_test_pkgfmt("snap", "15.04")
-        c = ClickReviewLint(self.test_name)
-        yaml = self._create_hashes_yaml()
-        self.set_test_hashes_yaml(yaml)
-        c.pkg_files = self._test_pkg_files
-        c.pkg_files.append("extrafile")
-        c.check_snappy_hashes()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-        name = c._get_check_name('hashes_extra_files')
-        m = r['error'][name]['text']
-        self.assertIn("found extra files not listed in hashes.yaml: extrafile",
-                      m)
+    # def test_check_snappy_hashes_extra(self):
+    #     '''Test check_snappy_hashes() - extra'''
+    #     self.set_test_pkgfmt("snap", "15.04")
+    #     c = ClickReviewLint(self.test_name)
+    #     yaml = self._create_hashes_yaml()
+    #     self.set_test_hashes_yaml(yaml)
+    #     c.pkg_files = self._test_pkg_files
+    #     c.pkg_files.append("extrafile")
+    #     c.check_snappy_hashes()
+    #     r = c.click_report
+    #     expected_counts = {'info': None, 'warn': 0, 'error': 1}
+    #     self.check_results(r, expected_counts)
+    #     name = c._get_check_name('hashes_extra_files')
+    #     m = r['error'][name]['text']
+    #     self.assertIn("found extra files not listed in hashes.yaml: extrafile",
+    #                   m)
 
     def test_snappy_config(self):
         '''Test check_snappy_config()'''
